@@ -6,6 +6,8 @@ import inspect
 import re
 import collections
 import weakref
+import copy
+
 
 def Initial(*args):
     return SelfExporter.default_model.initial(*args)
@@ -117,15 +119,18 @@ class Component(object):
         self.model = None  # to be set in Model.add_component
         self._export = _export
         if self._export:
-            try:
-                SelfExporter.export(self)
-            except ComponentDuplicateNameError as e:
-                # re-raise to hide the stack trace below this point -- it's irrelevant to the user
-                # and makes the error harder to understand
-                raise e
+            self._do_export()
+
+    def _do_export(self):
+        try:
+            SelfExporter.export(self)
+        except ComponentDuplicateNameError as e:
+            # re-raise to hide the stack trace below this point -- it's irrelevant to the user
+            # and makes the error harder to understand
+            raise e
 
     def rename(self, new_name):
-        self.model._rename_component(self, new_name)
+        self.model()._rename_component(self, new_name)
         if self._export:
             SelfExporter.rename(self, new_name)
         self.name = new_name
@@ -267,7 +272,7 @@ class MonomerPattern(object):
         # 1.
         sites_ok = self.is_site_concrete()
         # 2.
-        compartment_ok = not self.monomer.model.compartments or self.compartment
+        compartment_ok = not self.monomer.model().compartments or self.compartment
         return compartment_ok and sites_ok
 
     def is_site_concrete(self):
@@ -684,8 +689,10 @@ class Model(object):
 
     _component_types = (Monomer, Compartment, Parameter, Rule, Observable)
 
-    def __init__(self, name=None, _export=True):
+    def __init__(self, name=None, base=None, _export=True):
         self.name = name
+        self.base = base
+        self._export = _export
         self.monomers = ComponentSet()
         self.compartments = ComponentSet()
         self.parameters = ComponentSet()
@@ -696,9 +703,16 @@ class Model(object):
         self.reactions = []
         self.reactions_bidirectional = []
         self.initial_conditions = []
-        self._export = _export
         if self._export:
             SelfExporter.export(self)
+        if self.base is not None:
+            if not isinstance(self.base, Model):
+                raise ValueError("base must be a Model")
+            model_copy = copy.deepcopy(self.base)
+            for component in model_copy.all_components():
+                self.add_component(component)
+                component._do_export()
+            self.initial_conditions = model_copy.initial_conditions
 
     def reload(self):
         # forcibly removes the .pyc file and reloads the model module
@@ -767,7 +781,7 @@ class Model(object):
         for t, cset in zip(Model._component_types, self.all_component_sets()):
             if isinstance(other, t):
                 cset.add(other)
-                other.model = weakref.proxy(self)
+                other.model = weakref.ref(self)
                 break
         else:
             raise Exception("Tried to add component of unknown type '%s' to"
